<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 ist freie Software, aber die Entwicklung nimmt wertvolle Zeit in Anspruch.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Bitte &lt;a href=&apos;%1&apos;&gt;spende&lt;/a&gt; um die weitere Entwicklung von %2 zu unterstützen.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Veröffentlicht unter der &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Was du schon immer über %1 wissen wolltest, aber nie gewagt hast zu fragen</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Du möchtest vielleicht meine anderen Anwendungen auch ausprobieren:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, eine YouTube-Anwendung</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, ein YouTube-Musikplayer</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Übersetze %1 mit %2 in deine Muttersprache</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Lizensiert für: %1</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Geben Sie die Details Ihrer Lizenz ein</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Code:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Bitte lizensiere %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Diese Testversion ist abgelaufen.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Ohne Lizenz wird die Testversion der Anwendung in %1 Tagen ablaufen.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Mit dem Kauf der Vollversion unterstützt Du auch die viele Arbeit, die ich in %1 gesteckt habe.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Die Testversion benutzen</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Lizenz eingeben</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Lizenz kaufen</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>In der Vollversion kannst du mehr als %1 Titel in die Abspielliste einfügen und ohne Unterbrechungen Musik hören.</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Bei %1 kaufen</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Mehr erfahren</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Artist</source>
        <translation>Artist</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Jahr</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Beliebtheit</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Umgekehrte Reihenfolge</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sortieren nach</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Mehr erfahren</translation>
    </message>
</context>
<context>
    <name>ArtistListView</name>
    <message>
        <source>Track Count</source>
        <translation>Anzahl der Titel</translation>
    </message>
    <message>
        <source>Album Count</source>
        <translation>Anzahl der Alben</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Jahr</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Beliebheit</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Umgekehrte Reihenfolge</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sortieren nach</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Zurück</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Gehe zurück</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Willkommen bei &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 muss deine Musiksammlung scannen.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Verwende die Musiksammlung von iTunes</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Verwende %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Wähle einen Ordner...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 wird sich zu den Last.fm Webservices verbinden und Künstlernamen und Albumtitel weitergeben, um Albumcover, Biographien und weitere Infos zu erhalten.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Wenn du dabei Bedenken bezüglich deiner Privatsphäre hast, kannst du das Programm jetzt schließen.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Wo befindet sich deine Musiksammlung?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Wähle den Ordner deiner Musiksammlung</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Finde deine Sammlung</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Leeren</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Der Scanvorgang läuft bereits</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 scannt deine Musiksammlung.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 verwendet &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; um deine Musik zu katalogisieren.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Das wird einige Zeit in Anspruch nehmen, abhängig von der Größe deiner Sammlung und deiner Verbindungsgeschwindigkeit.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Hol dir einen Kaffee</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <source>Downloading update...</source>
        <translation>Lade Update herunter...</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Hier fallenlassen um zur Playlist hinzuzufügen</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Künstler</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Alben</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Ordner</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Wiedergabe</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Wiedergabe/Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Beende Wiedergabe nach dem aktuellen Song</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Nächster Song</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Vorheriger Song</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Lautstärke erhöhen</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Lautstärke verringern</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Stummschalten</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Vorwärtsspulen</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Rückwärtsspulen</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>Authentifizierung fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>Bei %1 einloggen</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Benutzername:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Passwort:</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation>Für einen %1 Account anmelden</translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;Benutzername&lt;/a&gt; oder &lt;a href=&apos;%2&apos;&gt;Passwort&lt;/a&gt; vergessen?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Zurück</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Gehe zur vorherigen Ansicht</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Zeige Informationen über den aktuellen Song</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;Vorheriger</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Gehe zum vorherigen Song</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Nächster</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Gehe zum nächsten Song</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Wiedergabe</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Beginne Wiedergabe</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Vollbild</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Wechsle zur Vollbildansicht</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Entfernen</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Entferne die ausgewählten Songs aus der Playlist</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Nach &amp;oben schieben</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Verschiebe die ausgewählten Songs in der Playlist nach oben</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Nach &amp;unten schieben</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Verschiebe die ausgewählten Songs in der Playlist nach unten</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Tschüss</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>Ändere den &amp;Musiksammlungsordner</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Wähle einen anderen Ordner für deine Musiksammlung</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Webseite</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 im Internet</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>&amp;Spenden</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Bitte unterstütze die weitere Entwicklung von %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informationen über %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Leeren</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Entferne alle Songs aus der Playlist</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>&amp;Zufallsmodus</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Spiele Songs in zufälliger Reihenfolge</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Wiederholung</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Beginne wieder beim ersten Song, nachdem alle Songs abgespielt wurden</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Stummschalten</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Anwendung</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Wiedergabe</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>Play&amp;list</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Drücke %1 um die Lautstärke zu erhöhen, %2 um sie zu verringern</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Öffne %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Musiksammlung wird aktualisiert...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Musiksammlung wird aktualisiert - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Musiksammlung wurde aktualisiert</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Schwerer Fehler: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Fehler: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Verlasse &amp;Vollbildansicht</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Verbleibende Zeit: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Lautstärke bei %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Stummgeschaltet</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Lautgeschaltet</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Vollversion bekommen</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 Version %2 ist jetzt verfügbar.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Später erinnern</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Updaten</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenster</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimieren</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>%1 kaufen</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>Nach diesem Titel &amp;stoppen</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>&amp;Scrobbling</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>Gespielte Titel an %1 senden</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>Von %1 &amp;ausloggen</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>Ein Problem &amp;melden...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <source>%1 finished scanning your music collection</source>
        <translation>%1 hat die Musiksammlung vollständig eingelesen</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Lass die Elemente hier fallen</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Playlist zu Ende</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Das ist nur die Demoversion von %1</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Sie erlaubt dir einige Songs abzuspielen, sodass du die Anwendung testen und sehen kannst, ob sie dir gefällt.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fortfahren</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Hol dir die Vollversion</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Es ist eine neue Version von %1 verfügbar!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 ist jetzt verfügbar. Du hast aktuell %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Würdest Du diese jetzt gerne runterladen?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Diese Version überspringen</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Mich später erinnern</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Update installieren</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Diese Demo ist auf nur %1 Titel in der Abspielliste beschränkt.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>Playlist ist leer</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 Songs - Gesamtlänge beträgt %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>Deine Suche ergab keinen Treffer.</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Songs</translation>
    </message>
</context>
</TS>